@@ -1,8 +1,12 @@
+import io
 import re
 from pdb import Pdb
 
-from rich import box, inspect
+from icecream import ic
+from rich import box
+from rich._inspect import Inspect
 from rich.console import Console
+from rich.layout import Layout
 from rich.panel import Panel
 from rich.pretty import pprint
 from rich.syntax import DEFAULT_THEME, Syntax
@@ -10,12 +14,14 @@ from rich.table import Table
 from rich.theme import Theme
 from rich.tree import Tree
 
-from pdbr.utils import make_layout
-
-LOCAL_VARS_CMD = ("nn", "uu", "dd")
+LOCAL_VARS_CMD = ("nn", "uu", "dd", "ss")
 ANSI_ESCAPE = re.compile(r"\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])")
 
 
+class AsciiStdout(io.TextIOWrapper):
+    pass
+
+
 def rich_pdb_klass(base, is_celery=False, context=None):
     class RichPdb(base):
         _style = None
@@ -49,21 +55,35 @@ def rich_pdb_klass(base, is_celery=False, context=None):
             super().__init__(**init_kwargs)
 
             self.prompt = "(Pdbr) "
-            custom_theme = Theme(
-                {"info": "dim cyan", "warning": "magenta", "danger": "bold red"}
-            )
-            self._console = Console(file=self.stdout, theme=custom_theme)
+
+        @property
+        def console(self):
+            if not hasattr(self, "_console"):
+                self._console = Console(
+                    file=(
+                        AsciiStdout(buffer=self.stdout.buffer, encoding="ascii")
+                        if is_celery
+                        else self.stdout
+                    ),
+                    theme=Theme(
+                        {"info": "dim cyan", "warning": "magenta", "danger": "bold red"}
+                    ),
+                    style=self._style,
+                )
+            return self._console
 
         def do_help(self, arg):
             super().do_help(arg)
-            self._print(
-                Panel(
-                    "Click the "
-                    "[bold][link=https://github.com/cansarigol/pdbr]link[/link][/]"
-                    " for more!"
-                ),
-                style="warning",
-            )
+            if not arg:
+                self._print(
+                    Panel(
+                        "Visit "
+                        "[bold][link=https://github.com/cansarigol/pdbr]"
+                        "https://github.com/cansarigol/pdbr[/link][/]"
+                        " for more!"
+                    ),
+                    style="warning",
+                )
 
         do_help.__doc__ = base.do_help.__doc__
         do_h = do_help
@@ -116,14 +136,14 @@ def rich_pdb_klass(base, is_celery=False, context=None):
         do_ll = do_longlist
 
         def do_vars(self, arg):
-            """
+            """v(ars)
             List of local variables
             """
 
             table = Table(title="List of local variables", box=box.MINIMAL)
 
-            table.add_column("Variable", style="cyan", no_wrap=True)
-            table.add_column("Value", style="magenta", no_wrap=True)
+            table.add_column("Variable", style="cyan")
+            table.add_column("Value", style="magenta")
             table.add_column("Type", style="green")
             [
                 table.add_row(variable, value, _type)
@@ -152,7 +172,7 @@ def rich_pdb_klass(base, is_celery=False, context=None):
             return tree
 
         def do_varstree(self, arg):
-            """
+            """varstree | vt
             List of local variables in Rich.Tree
             """
             self._print(self.get_varstree())
@@ -160,16 +180,16 @@ def rich_pdb_klass(base, is_celery=False, context=None):
         do_vt = do_varstree
 
         def do_inspect(self, arg, all=False):
-            """inspect
+            """(i)nspect
             Display the data / methods / docs for any Python object.
             """
             try:
-                inspect(self._getval(arg), console=self._console, methods=True, all=all)
+                self._print(Inspect(self._getval(arg), methods=True, all=all))
             except BaseException:
                 pass
 
         def do_inspectall(self, arg):
-            """inspectall
+            """inspectall | ia
             Inspect with all to see all attributes.
             """
             self.do_inspect(arg, all=True)
@@ -182,10 +202,23 @@ def rich_pdb_klass(base, is_celery=False, context=None):
             Rich pretty print.
             """
             try:
-                pprint(self._getval(arg), console=self._console)
+                pprint(self._getval(arg), console=self.console)
             except BaseException:
                 pass
 
+        def do_icecream(self, arg):
+            """ic(ecream) expression
+            Icecream print.
+            """
+            try:
+                val = self._getval(arg)
+                ic.configureOutput(prefix="🍦 |> ")
+                self._print(ic.format(arg, val))
+            except BaseException:
+                pass
+
+        do_ic = do_icecream
+
         def do_uu(self, arg):
             """uu
             Same with u(p) command + with local variables.
@@ -205,6 +238,13 @@ def rich_pdb_klass(base, is_celery=False, context=None):
 
             return self.do_next(arg)
 
+        def do_ss(self, arg):
+            """ss
+            Same with s(tep) command + with local variables.
+            """
+
+            return self.do_step(arg)
+
         def displayhook(self, obj):
             if obj is not None:
                 self._print(obj)
@@ -212,9 +252,18 @@ def rich_pdb_klass(base, is_celery=False, context=None):
         def error(self, msg):
             self._print(msg, prefix="***", style="danger")
 
+        def _make_layout(self):
+            if not hasattr(self, "layout"):
+                layout = Layout()
+                left_layout = Layout(name="left", ratio=2)
+                right_layout = Layout(name="right")
+                layout.split(left_layout, right_layout, direction="horizontal")
+                self.layout = layout
+            return self.layout
+
         def message(self, msg):
             if self.lastcmd in LOCAL_VARS_CMD:
-                layout = make_layout()
+                layout = self._make_layout()
                 layout["left"].update(msg)
                 layout["right"].update(Panel(self.get_varstree()))
                 self._print(layout)
@@ -223,17 +272,15 @@ def rich_pdb_klass(base, is_celery=False, context=None):
 
         def _print(self, val, prefix=None, style=None):
             args = (prefix, val) if prefix else (val,)
-
-            style = style or self._style
             kwargs = {"style": str(style)} if style else {}
 
-            self._console.print(*args, **kwargs)
+            self.console.print(*args, **kwargs)
 
         def print_stack_entry(self, frame_lineno, prompt_prefix="\n-> ", context=None):
             """
             Remove ipython color format.
             """
-            if base == Pdb:
+            if base == Pdb or is_celery:
                 Pdb.print_stack_entry(self, frame_lineno, prompt_prefix)
                 return
             self.message(
